.. change::
    :tags: bug, sql, sqlite
    :tickets: 6007
    :versions: 1.4.0

    Fixed issue where the CHECK constraint generated by :class:`_types.Boolean`
    or :class:`_types.Enum` would fail to render the naming convention
    correctly after the first compilation, due to an unintended change of state
    within the name given to the constraint. This issue was first introduced in
    0.9 in the fix for issue #3067, and the fix revises the approach taken at
    that time which appears to have been more involved than what was needed.